; ***********************************************************************
; * CANCORR macro *******************************************************
; ***********************************************************************
; * Function: CANCORR computes the canonical correlation between two    *
; *           sets of variables.                                        *
; *                                                                     *
; * Call:     (a b l) = CANCORR (x y)                                   *
; *                                                                     *
; * (!)       the rows of x and y must be equal for this example        *
; *           (modifications are straightforward)                       *
; *           p, q > 1                                                  *
; *                                                                     *
; * ->X       x  n x p  matrix                                          *
; *           y  n x q  matrix                                          *
; * X->       a  n x 1  matrix                                          *
; *           b  n x 1  matrix                                          *
; *           l  k x 1  matrix                                          *
; *                                                                     *
; * Example:  FUNC("examples\MVAcancorr")                                  *
; *           t = READ(mark)                                            *
; *           x = t[,1:2]                                               *
; *           y = t[,3:5]                                               *
; *           (a b l) = CANCORR(x y)                                    *
; *           gives the canonical correlation vectors a,b and canonical *
; *           correlations l                                            *
; *           for the mark data of Mardia, Kent and Bibby (1984)        *
; *           Mulitvariate Statistical Analysis.                        *
; *                                                                     *
; * See also: EIGSM (command)                                           *
; *                                                                     *
; ***********************************************************************
; ** Wolfgang Haerdle, 920225 *******************************************
; ***********************************************************************
proc (a b l)=MVAcancorr(x y)
  p=cols(x)
  q=cols(y)
  x=x~y
  s=cov(x)
  s11=s[1:p,1:p]                   ; define partial covariance matrices
  s22=s[(p+1):(p+q),(p+1):(p+q)]
  s12=s[(p+1):(p+q),1:p]
  (e1 v1)=eigsm(s11)               ; eigensystem analysis
  (e2 v2)=eigsm(s22)
  ie1=sqrt(1./e1)
  ie2=sqrt(1./e2)
  is11=v1*diag(ie1)*v1'
  is22=v2*diag(ie2)*v2'
  k=is11*s12'*is22
  k=k'
  (u l v)=svd(k)                   ; find the SVD of K
  a=is11*v                         ; canonical projections
  b=is22*u
endp
; ***********************************************************************
