; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also     uniform createdisplay while endo randomize sqrt sum
;               denest setmaskp setmaskl matrix grid show setgopt
; ----------------------------------------------------------------------------
;   Macro       MVAcltbern
; ----------------------------------------------------------------------------
;   Description  MVAcltbern illustrates the (univariate) Central Limit Theorem 
;                (CLT). ns sets of n-dimensional Bernoulli samples are 
;                generated and used to approximate the distribution of 
;                t = sqrt(n)*(mean(x)-mu)/sigma -> N(0,1). For n values 
;                from 5 to 35 are considered. The estimated density (red) of 
;                t is shown together with the standard normal (green) and  
;                the values of t (blue crosses). 
; ----------------------------------------------------------------------------
;
; subroutine for distribution
;
proc(y)=distribution(ns, n) 
  y=uniform(ns,n).>=0.5
endp
;
; main program (we have to use a program because of "while" loop
;
proc()=main()
  nl=5                           ; start value for n
  nu=35                          ; stop value for n
  ns=1000                        ; number of random samples  
  nstep=10                       ; step size for n  
;
  blue=1
  green=2
  red=4
  thin=2
  thick=5
  solid=1
  cross=11
  middlesize=8
;
  n=nl  
  di=createdisplay(1,1)
  while (n<=nu)  
    randomize(117117)            ; start always from same random seed
    x=distribution(ns,n) 
;
    t=sqrt(n).*(sum(x,2)./n-0.5)./sqrt(0.25)  ; statistic t
    t=sort(t)
;  
    dens=denest(t)               ; density estimate of t
    line=(1:(rows(dens)-1))~(2:rows(dens))
    setmaskp(dens,red,0,0) 
    setmaskl(dens,line,red,1,thick)   
;
    t=t~(0.*matrix(rows(t)))     ; append zeros to t for show
    setmaskp(t,blue,cross,middlesize) 
;
    ngrid=grid(-3,0.1,61)
    norm=ngrid~pdfn(ngrid)       ; normal density
    setmaskp(norm,green,0,0) 
    line=(1:60)~(2:61)
    setmaskl(norm,line,green,1,thin)   
;  
    show(di,1,1,t,norm,dens)
;
    titl="Asymptotic Distribution, N="+string("%1.0f",n)
    setgopt(di,1,1,"title",titl)
    xlabl=string("%1.0f",ns)+" Random. Samples"
    ylabl="Estimated and Normal Density"
    setgopt(di,1,1,"xlabel",xlabl,"ylabel",ylabl)
    n=n+nstep
  endo                             
endp
;
library("smoother")
main()
