; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also     randomize uniform sqrt sum denest2 grsurface createdisplay 
;               show 
; ----------------------------------------------------------------------------
;   Macro       MVAcltbern2
; ----------------------------------------------------------------------------
;   Description  MVAcltbern2 illustrates the (multivariate) Central Limit  
;                Theorem (CLT). ns sets of n-dimensional bivariate Bernoulli 
;                samples are  generated and used to approximate the 
;                distribution of t = sqrt(n)*inv(sigma)*(mean(x)-mu) 
;                -> N(0,I). 
;                The values of n should be varied (e.g. 4 .. 100).  
;                The estimated bivariate density of t is shown. 
; ----------------------------------------------------------------------------
       library("smoother")
       library("graphic")
       n=5                            ; number of observations
       ns=300                         ; number of random samples  
     ;
       randomize(117117)    
       x=uniform(ns,n,2).>=0.5
       x1=x[,,1]
       x2=x[,,2]
     ;    
       t1=sqrt(n).*(sum(x1,2)./n-0.5)./0.25    
       t2=sqrt(n).*(sum(x2,2)./n-0.5)./0.25    
       t=t1~t2    
     ;    
       h=2.61.*ns^(-1/6)              ; rule-of-thumb bandwidth
       dens=denestp(t, h, h/5)    
       gs=grsurface(dens)
     ;  
       di=createdisplay(1,1)
       show(di, 1, 1,gs)              ; shows t's         

