; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      agglom tree
; ----------------------------------------------------------------------------
;   Macro        MVAclusfood
; ----------------------------------------------------------------------------
;   Description  MVAclusfood performs cluster analysis for the french food data
; ----------------------------------------------------------------------------
library("xplore")
proc ()=main()
 x=read("food")                 ; reads the food data 
 cols=cols(x)
 names=readascii("food", " \t\n")
 names=names[1+(0:11)*9]
 x=x[,2:cols]
 ; 
 d=distance(x, "euclid")           ; Euclidean distance without weights 
 d.*d                           ; shows squared distance matrix 
 w=1./var(x)                    ; use 1/variances as weights 
 x
 w
 d=distance(x, "euclid", w')         ; Euclidean distance with weights 
 d.*d                           ; shows squared distance matrix 
 ; 
 t=agglom(d.*d, "WARD", 12)  ; hier. cluster analysis, Ward algor. 
 /*
 up=paf(u[,2] u[,2].<>0)        ; order of observations in dendrogram 
 xr=index(x$[,1] up)            ; reorder labels 
 n=rows(x)                      ; rows of data matrix 
 pi=matrix(n 1 (-1))~(0:n-1)~xr ; obs. point in dendrogram 
 */
 g=tree(t.g, 0, "CENTER"|"XAXIS")    ; builds dendrogram 
 g=g.points
 l = 5.*(1:rows(g)/5) + (0:4)' - 4 
 setmaskl (g, l, 0, 1, 1) 
 setmaskp (g, 0, 0, 0) 
 ; show the dendrogram 
 numbers=(0:(rows(x)-1))
 numbers=numbers~((-0.5)*matrix(rows(x)))
 setmaskp(numbers, 0, 0, 0)
 i=0
 tg=paf(t.g[,2], t.g[,2]!=0)  
 setmaskt(numbers, names[tg], 0, 6, 16)  
 dd=createdisplay(1,1)
 show(dd, 1, 1, g, numbers)                ; shows dendrogram -> BRUSH!! 
 setgopt(dd, 1, 1, "title", "Ward Dendrogram for French Food", "ylabel", "Squared Euclidian Distance", "xlabel", " ")
 setgopt(dd, 1, 1, "ylim",-2|35,"xmajor",0,"xlim",-1|12)
endp
     main()

