; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      grid sqrt pdfn setmaskp setmaskl createdisplay show setgopt 
; ----------------------------------------------------------------------------
;   Macro        MVAcondnorm
; ----------------------------------------------------------------------------
;   Description  MVAcondnorm computes conditonal normal densities f(x2|x1) where
;                the joint distribution has mean=0|0 and cov=(1|-0.8)~(-0.8|2).
; ----------------------------------------------------------------------------
  library("plot")
  o=#(0 ,-10)                      ; defines origin for grid
  h=#(0.75, 0.05)                 ; defines stepsize for grid
  n=#(7, 300)                     ; defines size of grid
  x=grid(o,h,n)                   ; grid  
;
  c=1.36                          ; variance of conditional pdf  
  c=sqrt(c)  
  f=pdfn((x[,2]+0.8*x[,1])/c)/c   ; densities on grid, x1=0,1,...,4  
  f=x~f 
  setmaskp(f,0,8,4) 
;
  x0=x[1:n[1],1]                
  m=x0~(-0.8*x0)~(0*matrix(n[1])) ; conditonal means
  setmaskp(m,4,11,12)
;
  r=max(x0)-min(x0)
  l0=(min(x0)-0.5*r)|(max(x0)+0.5*r)
  l=l0~(-0.8*l0)~(0|0)            ; line through conditional means
  setmaskp(l,0,0,0)
  setmaskl(l,1~2,0,1,2)
;
;  di=createdisplay(1, 1)
;  show(di, 1, 1, f, m, l)         ; show shifted densities (+ means)   
;
  f.data=f.data[,2|1|3]
  m.data=m.data[,2|1|3]
  l.data=l.data[,2|1|3]
  plot3d(2,f,m,l)
  titl ="conditional normal densities f(x2|x1)"
  xlabl="conditional values x1"
  ylabl="arguments for density x2"
  setgopt(plot3disp, 1, 1, "title",titl,"xlabel",xlabl,"ylabel",ylabl)

