; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also     sort rows matrix min max grid var sker grcontour2
;               createdisplay show
; ----------------------------------------------------------------------------
;   Macro       MVAcontbank2
; ----------------------------------------------------------------------------
;   Description  MVAcontbank2 computes a kernel density estimate of variables  
;                X5 and X6 of the Swiss bank notes ("bank2.dat"). The 
;                bandwidth parameter are chosen by Scott's rule of thumb.
; ----------------------------------------------------------------------------
  x=read("bank2")                  ; reads data file
  x=sort(x[,5:6])                  ; extracts columns 5, 6 and sorts
  library("smoother")              ; loads smoother library 
  library("graphic")               ; loads graphic library 
; 
  n=rows(x)
  nd=15                            ; number of grid points in each dimension
  nd=nd*matrix(cols(x))
  d=(max(x)-min(x))'./(nd-1)       ; binwidth in each dimension
  xg=sort(grid(min(x)',d,nd))
  h=2.6073*sqrt(var(x))*n^(-1/6)   ; bandwidth a la Scott's rule of thumb
  one=matrix(n)
  fh=sker(x,h,"qua",one,xg)        ; density estimate
;
  c  = (1:9)/10*max(fh)            ; computes contours at 10%..90% level
  color=(0:6)|(0:1)
  g = grcontour2(xg~fh,c,color)    ; macro for contours 
;
  di  = createdisplay (1,1)
  show (di, 1, 1, g)   
