; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also     sort rows matrix min max grid var sker grcontour3
;               createdisplay show
; ----------------------------------------------------------------------------
;   Macro       MVAcontbank3
; ----------------------------------------------------------------------------
;   Description  MVAcontbank3 computes a kernel density estimate of variables  
;                X4, X5 and X6 of the Swiss bank notes ("bank2.dat"). The 
;                bandwidth parameter are chosen by Scott's rule of thumb.
; ----------------------------------------------------------------------------
  x=read("bank2")                  ; reads data file
  x=sort(x[,4:6])                  ; extracts columns 4-6 and sorts
  library("smoother")              ; loads smoother library 
  library("graphic")               ; loads graphic library 
; 
  n=rows(x)
  nd=7                             ; number of grid points in each dimension
  nd=nd*matrix(cols(x))
  d=(max(x)-min(x))'./(nd-1)       ; binwidth in each dimension
  xg=sort(grid(min(x)',d,nd))
  h=2.5964*sqrt(var(x))*n^(-1/7)   ; bandwidth a la Scott's rule of thumb
  one=matrix(n)
  fh=sker(x,h,"qua",one,xg)        ; density estimate
;
  blue=1
  red=4
  green=2
  c = (0.2|0.4|0.6)*max(fh)        ; contours at 20%, 40%, 60% level
  color=(green|red|blue)
  g = grcontour3(xg~fh,c,color)    ; macro for contours 
;
  di  = createdisplay (1,1)
  show (di, 1, 1, g)   
