; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  paf sum svdcmp cumsum sqrt setmaskp setmaskt createdisplay grxline setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAcorrbac
; ----------------------------------------------------------------------------
;   Description  MVAcorrbac performs a correspondence analysis for the baccalaureat 
;                data ("bac.dat"), shows the eigenvalues of the 
;                singular value decomposition of the chi-matrix and displays 
;                graphical its factorial decomposition. 
; ----------------------------------------------------------------------------
       library("graphic")           ; load graphic library
       library("xplore")            ; load xplore library
     ;
       x=read("bac")                ; read data
       x=x[,2:cols(x)]
       xrows="ildf"|"cham"|"pica"|"hnor"|"cent"|"bnor"|"bour"|"nopc"
       xrows= xrows|"lorr"|"alsa"|"frac"|"payl"|"bret"|"pcha"|"aqui"
       xrows= xrows|"midi"|"limo"|"rhoa"|"auve"|"laro"|"prov"|"cors"
                                    ; labels for regions
       xcols="A"|"B"|"C"|"D"|"E"|"F"|"G"|"H" 
                                    ; labels for modalities
     ;
       wcors=0                      ; set to 0/1 to ex/include Corsica!!
     ;
       wcorsica=matrix(rows(x)-1)|wcors
       x    =paf(x    ,wcorsica)  
       xrows=paf(xrows,wcorsica)  
     ;
       a=sum(x,2)                   ; row sums
       b=sum(x)'                    ; column sums
       e=a*b'/sum(a)
     ;
       C=(x-e)./sqrt(e)             ; chi-matrix
       {g,l,d}=svd(C)               ; singular value decomposition
       (l^2)~cumsum(l^2)./sum(l^2)  ; eigenvalues & percentages
       r=((l'.*g)./sqrt(a))*(-1)
       s=((l'.*d)./sqrt(b))*(-1)
     ;
       r
       s
       p=rows(l)
       car=sum(x,2).*(r^2)/(l^2)'   ; contribution in r
       cas=sum(x)'.*(s^2)/(l^2)'    ; contribution in s
     ;car
     ;cas
     ;
       r=r[,1:2]
       s=s[,1:2]
     ;
       setmaskt(r,xrows,1,0,15)
       setmaskp(r,0,0,0)
       setmaskt(s,xcols,4,0,22)
       setmaskp(s,0,0,0)
     ;
       di=createdisplay(1,1)        ; create display
       xline=grxline(0,(1.2*r[,2])|(0.8*r[,2])|(1.2*s[,2])|(0.8*s[,2]))
       yline=gryline(0,(1.2*r[,1])|(0.8*r[,1])|(1.2*s[,1])|(0.8*s[,1]))
       show(di,1,1,r,s,xline,yline) 
                                    ; display with 0-axes
       setgopt(di,1,1,"title","baccalaureat data","xlabel","r_1,s_1","ylabel","r_2,s_2")