; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  paf sum svdcmp cumsum sqrt setmaskp setmaskt createdisplay grxline setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAcorrcrime
; ----------------------------------------------------------------------------
;   Description  MVAcorrcrime performs a correspondence analysis for the US crime 
;                ("uscrime.dat"), shows the eigenvalues of the singular value
;                decomposition of the chi-matrix and displays graphical its
;                factorial decomposition. 
; ----------------------------------------------------------------------------
  library("graphic")           ; load graphic library
  library("xplore")            ; load xplore library
;
  x=read("uscrime.dat")
  x=x[,3:(cols(x)-2)]
  xrows= "ME"|"NH"|"VT"|"MA"|"RI"|"CT"|"NY"|"NJ"|"PA"|"OH"|"IN"|"IL"|"MI"
  xrows = xrows|"WI"|"MN"|"IA"|"MO"|"ND"|"SD"|"NE"|"KS"|"DE"|"MD"
  xrows = xrows|"VA"|"WV"|"NC"|"SC"|"GA"|"FL"|"KY"|"TN"|"AL"|"MS"|"AR"|"LA"|"OK"
  xrows = xrows|"TX"|"MT"|"ID"|"WY"|"CO"|"NM"|"AZ"|"UT"|"NV"|"WA"|"OR"|"CA"|"AK"|"HI"          
                               ; labels for regions
  xcols="mur"|"rap"|"rob"|"ass"|"bur"|"lar"|"aut"
                               ; labels for crimes
;
      
  a=sum(x,2)                   ; row sums
  b=sum(x)'                    ; column sums
  e=a*b'/sum(a)
;
  C=(x-e)./sqrt(e)             ; chi-matrix
  {g,l,d}=svd(C)               ; singular value decomposition
  (l^2)~cumsum(l^2)./sum(l^2)  ; eigenvalues & percentages
;
  r=(l'.*g)./sqrt(a)
  s=(l'.*d)./sqrt(b)
  r=r[,1:2]
  s=s[,1:2]
;
  setmaskt(r,xrows,1,0,15)
  setmaskp(r,0,0,0)
  setmaskt(s,xcols,4,0,15)
  setmaskp(s,0,0,0)
;
  di=createdisplay(1,1)        ; create display
  xline=grxline(0,(1.2*r[,2])|(0.8*r[,2])|(1.2*s[,2])|(0.8*s[,2]))
  yline=gryline(0,(1.2*r[,1])|(0.8*r[,1])|(1.2*s[,1])|(0.8*s[,1]))
  show(di,1,1,r,s,xline,yline) 
                               ; display with 0-axes
  setgopt(di,1,1,"title","uscrime data","xlabel","r_1,s_1","ylabel","r_2,s_2")
