; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  paf sum svdcmp cumsum sqrt setmaskp setmaskt createdisplay grxline setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAcorrjourn
; ----------------------------------------------------------------------------
;   Description  MVAcorrjourn performs a correspondence analysis for the Belgian 
;                journal data ("journaux.dat"), shows the eigenvalues of the 
;                singular value decomposition of the chi-matrix and displays 
;                graphical its factorial decomposition. 
; ----------------------------------------------------------------------------
       library("graphic")           ; load graphic library
       library("xplore")            ; load xplore library
     ;
       x=read("journaux")           ; read data
       xrows="va"|"vb"|"vc"|"vd"|"ve"|"ff"|"fg"|"fh"|"fi"
       xrows=xrows|"bj"|"bk"|"bl"|"vm"|"fn"|"fo"
                                    ; labels for journals
       xcols="brw"|"bxl"|"anv"|"brf"|"foc"|"for"|"hai"|"lig"|"lim"|"lux"
                                    ; labels for regions
     ;
       a=sum(x,2)                   ; row sums
       b=sum(x)'                    ; column sums
       e=a*b'/sum(a)
     ;
       C=(x-e)./sqrt(e)             ; chi-matrix
       {g,l,d}=svd(C)            ; singular value decomposition
       (l^2)~cumsum(l^2)./sum(l^2)  ; eigenvalues & percentages
       r=(l'.*g)./sqrt(a)
       s=(l'.*d)./sqrt(b)
     ;
       p=rows(l)
       car=sum(x,2).*(r^2)/(l^2)'   ; contribution in r
       cas=sum(x)'.*(s^2)/(l^2)'    ; contribution in s
     car
     cas
     ;
       r=r[,1:2]
       s=s[,1:2]
     ;
       setmaskt(r,xrows,1,0,22)
       setmaskp(r,0,0,0)
       setmaskt(s,xcols,4,0,15)
       setmaskp(s,0,0,0)
     ;
       di=createdisplay(1,1)        ; create display
       xline=grxline(0,(1.2*r[,2])|(0.8*r[,2])|(1.2*s[,2])|(0.8*s[,2]))
       yline=gryline(0,(1.2*r[,1])|(0.8*r[,1])|(1.2*s[,1])|(0.8*s[,1]))
       show(di,1,1,r,s,xline,yline) 
                                    ; display with 0-axes
       setgopt(di,1,1,"title","journal data","xlabel","r_1,s_1","ylabel","r_2,s_2")

