; ***********************************************************************
; * CORRSPA macro *******************************************************
; ***********************************************************************
; * Function: CORRSPA performs a correspondence analysis                *
; *           of a data matrix x                                        *
; *                                                                     *
; * Call:     (r s) = CORRSPA (x)                                       *
; *                                                                     *
; * ->X       x  n x p  matrix                                          *
; * X->       r         eigenvectors of first coordinate                *
; *           s         eigenvector of second coordinate                *
; *                                                                     *
; * Example:  x = READ(bac)                                             *
; *           (r s) = CORRSPA(x)                                        *
; *           SHOW(r s s2d)                                             *
; *           gives the correspondence analysis                         *
; *           for the french baccalaureat data                          *
; *                                                                     *
; * Comments: See Saporta                                               *
; *                                                                     *
; ***********************************************************************
; ** Sigbert Klinke, 960226 *********************************************
; ***********************************************************************
proc (r s)=MVAcorrspa(x)
  xip = sumr(x)
  xpj = sum(x)
  eij = trn(xpj).*matrix(rows(xip) rows(xpj) xip./sum(xip))
  error (min(min(abs(eij))).< 1.0e-12 "CORRSPA : Empty row or column")
  cij = (x - eij)./sqrt(eij)
  (g l d)=svd(cij)
  r1 = (cij./sqrt(xip))*d[,1]
  r2 = (cij./sqrt(xip))*d[,2]
  s1 = (cij'./sqrt(xpj))*g[,1]
  s2 = (cij'./sqrt(xpj))*g[,2]
l
s1~s2
  r = (l[1,1].*r1)~(l[2,1].*r2)
r1~r2
  s = (l[1,1].*s1)~(l[2,1].*s2)
endp
; ***********************************************************************
