; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      mean cov inv sum
; ----------------------------------------------------------------------------
;   Macro        MVAdisbank
; ----------------------------------------------------------------------------
;   Description  MVAdisbank perform a ML discrimination analysis on a subsample
;                of the Swiss bank notes ("bank2.dat") and computes the
;                missclassification rates for the whole dataset.
; ----------------------------------------------------------------------------
  library("xplore")
  x=read("bank2")            ; reads the bank data
;
  i1=3|32|37|50|67|89|98
  i2=108|114|116|135|145|146|148|165|168|171|173|193|194
;
  x1=x[i1]                   ; bank notes cluster 1
  x2=x[i2]                   ; bank notes cluster 2
  n1=rows(x1)
  n2=rows(x2)
;
; calculate discrimination rule
;
  s1=cov(x1)             
  s2=cov(x2)    
  s=(s1*n1+s2*n2)./(n1+n2-2) ; mean covariance
;
  m1=mean(x1)'              
  m2=mean(x2)'              
  m=(m1*n1+m2*n2)/(n1+n2)    ; mean of all notes
  m
;
  alpha=inv(s)*(m1-m2)       ; alpha
  alpha 
;
; classify whole sample
;
  xg=x[  1:100]              ; genuine bank notes
  xf=x[101:200]              ; forged bank notes
;
  xgtest=(xg-m')*alpha
  sum(xgtest.<0)             ; counts number of misclassified
                             ; genuine bank notes
  xftest=(xf-m')*alpha
  sum(xftest.>0)             ; counts number of misclassified
                             ; forged bank notes      
