; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      mean cov inv sum denest setmaskp setmaskl createdisplay show setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAdisfbank
; ----------------------------------------------------------------------------
;   Description  MVAdisfbank perform a fisher discrimination analysis 
;                of the Swiss bank notes ("bank2.dat"), computes the
;                miss-classification rates for the whole dataset and
;                displays nonparametric density estimates of the projected 
;                data.
; ----------------------------------------------------------------------------
  library("xplore")
  x=read("bank2")         ; reads the bank data
;
  xg=x[  1:100]           ; genuine bank notes
  xf=x[101:200]           ; forged bank notes
; 
  mg=mean(xg)             ; mean of genuine notes
  mf=mean(xf)             ; mean of forged notes
  m=(mf+mg)/2             ; mean of all notes
;
  w=99*(cov(xg)+cov(xf))  ; matrix w for within-sum-of-squares
  d=mg-mf                 ; vector d
  a=inv(w)*d'             ; inverse of w times d
;
  yg=(xg-m)*a             ; projection of genuine notes
  yf=(xf-m)*a             ; projection of forged notes
;
  xgtest=(xg-m)*a
  sum(xgtest.<0)          ; counts number of misclassified
                          ; genuine notes 
  xftest=(xf-m)*a 
  sum(xftest.>0)          ; counts number of misclassified  
                          ; genuine notes  
;   
  library("smoother")
  fhg=denest(yg)          ; density of proj. of genuine notes       
  fhf=denest(yf)          ; density of proj. of forged notes       
;
  p1=mean(yf)|mean(yg)                  
  p2=(fhf[ceil(rows(fhf)/2),2]|fhg[ceil(rows(fhg)/2),2])/3
  p=p1~p2                         ; vector of points for labels
  setmaskp(p,0,0,0)
  text="Forged"|"Genuine"         ; labels
  setmaskt(p,text,4|1,0,16)         ; set labels

;
  setmaskl(fhg, (1:100)',1, 1, 2)    ; creates a solid line for 
  setmaskp(fhg, 0, 0, 0)          ; the density function 
  setmaskl(fhf, (1:100)',4, 1, 2)    ; creates a solid line for 
  setmaskp(fhf, 0, 0, 0)          ; the density function
;
  di=createdisplay(1, 1)
  show(di, 1, 1, fhg, fhf, p)       
  setgopt(di, 1, 1, "title","Swiss bank notes","xlabel"," ","ylabel","densities of projections","ymajor",3)


