; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      grid pdfn sqrt setmaskp setmaskl grxline createdisplay show setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAdisnorm
; ----------------------------------------------------------------------------
;   Description  MVAdisnorm displays graphically the maximum likelihood (ML)
;                discrimination rule for 2 normal distributed samples. The 
;                inner interval is the allocation set for N(1,0.25), the outer
;                intervals are for observations from N(0,1)
; ----------------------------------------------------------------------------  

library("graphic")             ; contains "grxline"
 t=grid(-3, 0.05, 121)          ; creates grid on real axis
 f1=t~pdfn(t)                   ; density f1
 s2=0.5                         ; square root of variance for f2
 mu2=1                          ; mean for f2
 f2=t~pdfn((t-mu2)/s2)/s2       ; density f2
 p1=-1|1.3|2.8                  
 p2=0.4|0.4|0.4
 p=p1~p2                        ; vector of points for labels
 setmaskp(p,0,0,0)
 text="R1"|"R2"|"R1"            ; labels
 setmaskt(p,text,4,0,16)        ; set labels
;
 c1=4/3-sqrt(4+6*log(2))/3      ; first discrimination point
 c2=4/3+sqrt(4+6*log(2))/3      ; second discrimination point
; 
 setmaskl(f1, (1:121)',0, 1)    ; creates a solid line for 
 setmaskp(f1, 0, 0, 0)          ; the density function 
 setmaskl(f2, (1:121)',0, 1)    ; creates a solid line for 
 setmaskp(f2, 0, 0, 0)          ; the density function
;
 l1=grxline(c1, 0 | max(max(f1[,2])|max(f2[,2])))        ; creates a solid line for c1
 l2=grxline(c2, 0 | max(max(f1[,2])|max(f2[,2])))      ; creates a solid line for c2
 di=createdisplay(1, 1)
 show(di, 1, 1, f1, f2, l1, l2,p)  ; commands for display
 setgopt(di, 1, 1, "title", "2 Normal distributions","xlabel"," ","ylabel","densities","xmajor",1.5)

