; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  corr diag xdiag eigsm setmaskp setmaskt createdisplay grxline setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAfactcarm
; ----------------------------------------------------------------------------
;   Description  MVAfactcarm performs a factor analysis for the car marks data
;                ("carmean.dat") and shows the eigenvalues of r-psi and a 
;                plot of the factor loadings for the first two factors.
; ----------------------------------------------------------------------------
  library("graphic")       ; load graphic library
  library("xplore")        ; load xplore library
;
  x=read("carmean")        ; read data
  x=x[,2:9]
  xvars="economic"|"service"|"value"|"price"|"look"
  xvars=xvars|"sporty"|"security"|"easy"
                           ; define variable names
;
  r=corr(x)                ; correlation matrix
 m=r-diag(xdiag(r))
psi=1-diag(max(abs(m))') ; preliminary estimate for psi
;id=unit(rows(r)) 
;psi=max(abs(r-id))             ; first estimator for psi
;psi=psi'  
;r
;psi=diag(psi)       
  {e,v}=eigsm(r-psi)       ; spectral decomposition
  tmp=sort(e~v',-1)        ; sort by eigenvalues
  e=tmp[,1]
  v=tmp[,2:9]'
  e                        ; inspection of eigenvalues
;
  e=e[1:2]                 
  v=v[,1:2]
  q=sqrt(e)'.*v            ; loading of first 2 factors
  setmaskt(q,xvars,0,0,15)
  setmaskp(q,0,0,0)
;
  di=createdisplay(1,1)    ; create display
  xline=grxline(0,(1.2*q[,2])|(0.8*q[,2]))
  yline=gryline(0,(1.2*q[,1])|(0.8*q[,1]))
  show(di,1,1,q,xline,yline) 
                           ; display loadings with 0-axes
  setgopt(di,1,1,"title","car marks data","xlabel","first factor","ylabel","second factor")
