; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      mean cov eigsm sort diag
; ----------------------------------------------------------------------------
;   Macro        MVAmahabank
; ----------------------------------------------------------------------------
;   Description  MVAmahabank computes a spectral decomposition of covariance
;                matrix of the Swiss bank notes ("bank2.dat") and does a
;                Mahalanobis transformation       
; ----------------------------------------------------------------------------
  library("xplore")          ; xplore library, contains "cov"
  x=read("bank2")            ; reads the bank data
  x=x[1:100,]                ; genuine bank notes
;
  s=cov(x)                   ; empirical covariance
  {lambda,gamma}=eigsm(s)    ; spectral decomposition
;
  tmp=sort(lambda~gamma',-1) ; sort by eigenvalues
  lambda=tmp[,1]
  gamma=tmp[,2:cols(tmp)]'
;
  lambda                     ; eigenvalues
  gamma                      ; eigenvectors
;
  lambda2=1./sqrt(lambda)    ; computes lambda to the power -1/2
  lambda2=diag(lambda2)      ; makes diagonal matrix from lambda2   
  s2=gamma*lambda2*gamma'    ; computes s to the power -1/2    
  x=x-mean(x)                ; corrects for mean    
  z=x*s2                     ; Mahalanobis transformation   
; 
  mean(z)                    ; show mean of z    
  cov(z)                     ; show empirical covariance of z    
    
