; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  distance eigsm corr setmaskp setmaskt createdisplay show setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAmdscarm
; ----------------------------------------------------------------------------
;   Description  MVAmdscarm performs a multidimensional scaling (MDS)
;                for the car marks data ("carmean2.dat") and shows 
;                a plot of the MDS and the MDS/variables correlations.
; ----------------------------------------------------------------------------
  library("xplore")
;
  x=read("carmean2")
  x=x[,2:9]
;
  xvars="economic"|"service"|"value"|"price"|"look"
  xvars=xvars|"sporty"|"security"|"easy"
                           ; define variable names
;
  xrows="audi"|"bmw"|"citroen"|"ferrari"
  xrows=xrows|"fiat"|"ford"|"hyundai"|"jaguar"
  xrows=xrows|"lada"|"mazda"|"mercedes"|"mitsubishi"
  xrows=xrows|"nissan"|"opel_corsa"|"opel_vectra"
  xrows=xrows|"peugeot"|"renault"|"rover"|"toyota"
  xrows=xrows|"trabant"|"vw_golf"|"vw_passat"|"wartburg"
;
  d=distance(x)^2               ; squared distance matrix
;
  B=-0.5*(d-mean(d)-mean(d,2)+mean(mean(d,2)))
                                ; B=HXX'H
  {e,v}=eigsm(B)                ; spectral decomposition
  tmp=sort(e~v',-1)             ; sort by eigenvalues
  e=tmp[,1]
  v=tmp[,2:cols(tmp)]'
;
  D=v[,1:2].*sqrt(e[1:2]')
  setmaskt(D,xrows,0,0,15)      ; add text labels
  setmaskp(D,0,0,0)             ; no points
;
  setsize(800,400)
  di=createdisplay(1,2)
  show(di,1,1,D)
  setgopt(di,1,1, "title", "Metric MDS")
;
  c=corr(D~x)
  c=c[3:rows(c),1:2]
  setmaskt(c,xvars,0,0,15)      ; add text labels
  setmaskp(c,0,0,0)             ; no points
;
  circle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
  setmaskp(circle,0,0,0)
  setmaskl(circle,(0:360)',0,1,2)
;
  show(di,1,2,c,circle)
  setgopt(di,1,2, "title", "Correlations MDS/Variables")
  setsize(500,500)


