; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  eigsm sort setmaskp setmaskl createdisplay setfractions setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAnpcabanki
; ----------------------------------------------------------------------------
;   Description  MVAnpcabanki shows a screeplot of the eigenvalues for the PCA of
;                the standardized Swiss bank notes ("bank2.dat"). It computes
;                the correlations between the variables and the principal 
;                components and displays the first two of them.
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
x=read("bank2")                      ; read data
n=rows(x)
x=(x-mean(x))./sqrt((n-1)*var(x)/n)  ; standardize
;
{e,v}=eigsm((n-1)*cov(x)/n)          ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:7]'
;
r=(x-mean(x))*v
r=corr(r~x)
r=r[7:12,1:2]                        ; correlations between variables and pc's
r=setmask(r,"text","x1"|"x2"|"x3"|"x4"|"x5"|"x6")
;
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
ucircle=setmask(ucircle,"line","thin","dashed")
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
;
die=createdisplay(1,1)
show(die,1,1,(1:6)~e)
setgopt(die,1,1,"title","Swiss bank notes","xlabel","index","ylabel","lambda")
dic=createdisplay(1,1)
show(dic,1,1,r,ucircle,xline,yline)
setgopt(dic,1,1,"title","Swiss bank notes","xlabel","first PC","ylabel","second PC")
