; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  eigsm sort setmaskp setmaskl createdisplay setfractions setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAnpcafood
; ----------------------------------------------------------------------------
;   Description  MVAnpcafood performs a PCA for the standarized French food data
;                ("food.dat") and shows the first two principal components 
;                in for the individuals and the variables. The normalization
;                corresponds to that of Lebart/Morineau/Fenelon.
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
x=read("food")
x=x[,2:8]
n=rows(x)
p=cols(x)
x=(x-mean(x))./sqrt((n-1)*var(x)/n)
;
{e,v}=eigsm((x*x')/n)                ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:n+1]
w=(v[1:2]'.*sqrt(e[1:2]'))
;
diw=createdisplay(1,1)
xline=setmask(#(min(w[,1]),max(w[,1]))~#(0,0),"line")
yline=setmask(#(0,0)~#(min(w[,2]),max(w[,2])),"line")
l=#(1,4,7,10)'+#(0,1,2)
l=l|(l'~0.*matrix(4))
fams="MA2"|"EM2"|"CA2"|"MA3"|"EM3"|"CA3"|"MA4"|"EM4"|"CA4"|"MA5"|"EM5"|"CA5"
w=setmask(w,"line",l,"dashed","text",fams)
show(diw,1,1,w,xline,yline)
setgopt(diw,1,1,"title", "French food data","xlabel","first factor - families","ylabel","second factor - families")
;
{e,v}=eigsm((x'*x)/n)                ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:p+1]
z=-(v[1:2]'.*sqrt(e[1:2]'))
"hier"
z=setmask(z,"text","bread"|"vegetables"|"fruits"|"meat"|"poultry"|"milk"|"wine")
"hier2"
;
diz=createdisplay(1,1)
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
ucircle=setmask(ucircle,"line","dashed","thin")
show(diz,1,1,z,xline,yline,ucircle)
setgopt(diz,1,1,"title","French food data","xlabel","first factor - goods","ylabel","second factor - goods")

