; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      eigsm sort setmaskp createdisplay show setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAnpcahous
; ----------------------------------------------------------------------------
;   Description  MVAnpcahous performs a PCA for the standarized Boston housing data
;                ("bostonh.dat"). It shows the first two principal components and 
;                a screeplot of the eigenvalues.
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
;
x=read("bostonh")                      ; reads the data file
library("graphic")                     ; loads the graphic library

xt=x
xt[,1]=log(x[,1])
xt[,2]=x[,2]/10
xt[,3]=log(x[,3])
xt[,5]=log(x[,5])
xt[,6]=log(x[,6])
xt[,7]=(x[,7]^(2.5))/10000
xt[,8]=log(x[,8])
xt[,9]=log(x[,9])
xt[,10]=log(x[,10])
xt[,11]=exp(0.4*x[,11])/1000
xt[,12]=x[,12]/100
xt[,13]=sqrt(x[,13])
xt[,14]=log(x[,14])
xt=xt~(x[,14]>median(x[,14]))

color=xt[,15]*4
x=xt[,1:3|5:14]                            

n=rows(x)
x=(x-mean(x))./sqrt((n-1)*var(x)/n)  ; standardize
;
{e,v}=eigsm((n-1)*cov(x)/n)          ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:cols(tmp)]'
;
setenv("outputformat","% 8.4f")
e~(e/sum(e))~cumsum(e)/sum(e)
v
;
axeson()
di=createdisplay(1,1)                
xv=x*v                                ; principal components
corr(xv~x)[14:26,1:3]
x12=setmask(xv[,1:2],"color",color,"style",(4*(color==0)+2*(color==4)),"size",5)
show(di,1,1,x12)
setgopt(di,1,1,"title","first  vs. second PC","xlabel","pc1","ylabel","pc2")

di2=createdisplay(1,1)                
color2=4*xt[,4]
x12ch=setmask(xv[,1:2],"color",color2,"style",(4*(color2==0)+2*(color2==4)),"size",5)
show(di2,1,1,x12ch)
setgopt(di2,1,1,"title","first  vs. second PC","xlabel","pc1","ylabel","pc2")




