; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  eigsm sort setmaskp setmaskl createdisplay setfractions setgopt
; ----------------------------------------------------------------------------
;   Macro        MVAnpcatime
; ----------------------------------------------------------------------------
;   Description  MVAnpcatime performs a PCA for the standardized time budget data 
;                ("timebudget.dat") and shows the first two principal components 
;                in for the individuals and the variables. 
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
x=read("timebudget")
n=rows(x)
p=cols(x)
x=(x-mean(x))./sqrt((n-1)*var(x))  ; normalize variance by n
;
{e,v}=eigsm((x*x')/n)                    ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:n+1]
w=(v[1:2]'.*sqrt(e[1:2]'))
w
;
diw=createdisplay(1,1)
xline=setmask(#(min(w[,1]),max(w[,1]))~#(0,0),"line")
yline=setmask(#(0,0)~#(min(w[,2]),max(w[,2])),"line")
fams="maus"|"waus"|"wnus"|"mmus"|"wmus"|"msus"|"wsus"|"mawe"|"wawe"
fams=  fams|"wnwe"|"mmwe"|"wmwe"|"mswe"|"wswe"|"mayo"|"wayo"|"wnyo"
fams=  fams|"mmyo"|"wmyo"|"msyo"|"wsyo"|"maes"|"waes"|"wnes"|"mmes"
fams=  fams|"wmes"|"mses"|"wses"
w=setmask(w,"text",fams)
show(diw,1,1,w,xline,yline)
setgopt(diw,1,1,"title", "time budget data","xlabel","first factor - individuals","ylabel","second factor - individuals")
;
{e,v}=eigsm(x'*x)                    ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:p+1]
z=(v[1:2]'.*sqrt(e[1:2]'))
z
z
z=setmask(z,"text","prof"|"tran"|"hous"|"kids"|"shop"|"pers"|"eati"|"slee"|"tele"|"leis","size",16)
;
diz=createdisplay(1,1)
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
ucircle=setmask(ucircle,"line","dashed","thin")
show(diz,1,1,z,xline,yline,ucircle)
setgopt(diz,1,1,"title","time budget data","xlabel","first factor - expenditures","ylabel","second factor - expenditures")
;
; first 4 w-factors
;
{e,v}=eigsm((x*x')/n)                ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:n+1]
w=(v[1:4]'.*sqrt(e[1:4]'))
w
;
r=corr(w~x)
r=r[cols(w)+1:cols(r),1:cols(w)]
r

