; ***********************************************************************
; * PCA macro ***********************************************************
; ***********************************************************************
; * Function: PCA performs a Principal Components Analysis for x        *
; *                                                                     *
; * Call:     y = PCA (x)                                               *
; *                                                                     *
; * ->X       x  n x p  matrix                                          *
; * X->       y  n x p  matrix                                          *
; *                                                                     *
; * (!)       the cols of X must be greater than 2.                     *
; *                                                                     *
; * Example:  x = READ(bank2)                                           *
; *           y = PCA(x)                                                *
; *           shows the first three principal components and a scree    *
; *           plot of the eigenvalues                                   *
; *                                                                     *
; ***********************************************************************
; ** Wolfgang Haerdle, 910426 *******************************************
; ***********************************************************************
proc (y)=MVApca(x)
  error(cols(x).<3  "PCA: COLS OF X LESS THAN 3")
  m=mean(x)
  c=cov(x)
  (a b)=eigsm(c)               ; eigensystem analysis
  c=a~trn(b)
  c=sort(c (-1))               ; descending sort w.r.t. eigenvalues
  e=c[,1]
  v=trn(c[,2:cols(c)])
  y=(x-m')*v                   ; PCA transformation
  createdisplay(t, 2 2, s2d)
  z1=y[,1]~y[,2]
  z2=y[,1]~y[,3]
  z3=y[,2]~y[,3]
  z4=(1:cols(x))~e
;** now show the first three principal components and the scree plot
  show(z1 s2d1, z2 s2d2, z3 s2d3, z4 s2d4)
endp
; ***********************************************************************




