; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also  gennorm eigsm sort setmaskp setmaskl createdisplay setfractions show setgopt
; ----------------------------------------------------------------------------
;   Macro        MVApcasimu
; ----------------------------------------------------------------------------
;   Description  MVApcasimu simulates a projection of a (normal) point cloud 
;                which may capture differnt proportions of the variance.
;                one should vary "nu" to see the effects.
;                (The chosen direction is always a linear combination of
;                the first and second PCA direction.)     
; ----------------------------------------------------------------------------
nu=0.0                          ; vary between 0 and 1 !!
;
randomize(961211)
func("gennorm")
n=200
rho=0.5
mu =0|0
sig=(1~rho)|(rho~1)
x=gennorm(n,mu,sig)             ; generate normal data with mu and sig
;
{l,g}=eigsm(sig)                ; spectral analysis
tmp=sort(l~g',-1)               ; sort by eigenvalues
l=tmp[,1]
g=tmp[,2:3]
;
direction=nu*g[1]'+(1-nu)*g[2]' ; convex combination from eigenvectors
norm=direction'*direction
direction=direction./sqrt(norm) ; normalize direction vector
pd=sort(x*direction)
d3=pd*direction'
d4=x[,1]~(0.*matrix(n))
setmaskp(d3,0,0,0)
setmaskp(d4,0,0,0)
setmaskl(d3,(1:n)',0,1,2)
;
di=createdisplay(3,1)
setfractions(di, 3|1|1, 1)
show(di,1,1,x,d3)
setgopt(di,1,1,"title","Direction in Data")
show(di,2,1,pd~(0.*matrix(n)),d4)
setgopt(di,2,1,"title","Projection","xlim",-3.8|3.8,"xmajor",1)
varexp=var(pd)
varsum=sum(var(x)')
varperc=varexp/varsum
varshow=varexp|varsum|varperc
v=string ("  %5.2f", varshow)
vtxt="  explained variance"|"      total variance"
vtxt=vtxt|"explained percentage"
show(di,3,1,vtxt+v)