; ---------------------------------------------------------------------
; EBook       mva
; ---------------------------------------------------------------------
; See_also    ppftind
; ---------------------------------------------------------------------
; Macro       MVAppexample
; ---------------------------------------------------------------------
; Description We read the Swiss banknote data and sphere them to run 
;             EPP on them. We select n (=50) randomly choosen one 
;             dimensional projections in the six dimensional space of
;             the data. For each set of projected data the 
;             Friedman-Tukex-Index is applied to judge the 
;             "interestingness" of the projection.
;
;             In the graphics we see the density for the standard
;             normal distributed data (green) and the estimated
;             densities for the best (red) and the worst (blue)
;             projections found. Additionally we see a dotplot
;             of the projections. Below we see the estimated value
;             of the Friedman-Tukey index for each computed projection 
;             (green = standard normal, red = best, blue = worst).
; ---------------------------------------------------------------------
; Author      Sigbert Klinke, 011102
; ---------------------------------------------------------------------
proc()=ppexample(x, h, n)
  xg   = grid(-4, 0.1, 81)
  zd   = setmask(xg~pdfn(xg), "line", "green")
; select a starting vector
  p    = normal(cols(x))
  p    = p/sqrt(sum(p^2))
; compute index for starting vector
  xp   = x*p
  imin = ppftind(xp, h)
  imax = imin  
  xi   = setmask(grdot(xp), "blue")
  xi[,2] = -0.11-0.08*xi[,2]
  fi   = setmask(denxest(xp, h, "rqua", xg), "line", "blue")
  xa   = setmask(grdot(xp), "red")
  xa[,2] = -0.1-0.08*xa[,2]
  fa   = setmask(denxest(xp, h, "rqua", xg), "line", "red")
; create display 
  d    = createdisplay (2,1)
  setfractions(d,2|1,1)
  show (d, 1, 1, zd, xa, fa, xi, fi)
  inds = 1/sqrt(4*pi)|imax
  pind = (1:rows(inds))~inds
  cind = 2|1
  setmaskp (pind, cind)
  show (d, 2, 1, pind)
; search for better projection vector
  i    = 0
  pmin = 1
  pmax = 1
  while (i<n)
    i   = i+1
    p   = normal(cols(x))
    p   = p/sqrt(sum(p^2))
    xp  = x*p
    ind = ppftind(xp, h)
;    xi   = setmask(grdot(xp))
;    xi[,2] = -0.1.*xi[,2]
;    fi   = setmask(denxest(xp, h, "rqua", xg), "line")
;    show (d, 1, 1, zd, xs, fs, xf, ff, xi, fi)
    inds = inds|ind
    pind = (1:rows(inds))~inds
    cind = 0.*matrix(rows(pind))
    cind[maxind(inds)] = 4
    cind[minind(inds)] = 1
    cind[1] = 2
    setmaskp(pind, cind)
    show (d, 2, 1, pind)
    if (ind>imax)
      imax = ind
      xa   = setmask(grdot(xp), "red")
      xa[,2] = -0.01-0.08.*xa[,2]
      fa   = setmask(denxest(xp, h, "rqua", xg), "line", "red")
      show (d, 1, 1, zd, xa, fa, xi, fi)
      pmin = i
    endif      
    if (ind<imin)
      imin = ind
      xi   = setmask(grdot(xp), "blue")
      xi[,2] = -0.11-0.08*xi[,2]
      fi   = setmask(denxest(xp, h, "rqua", xg), "line", "blue")
      show (d, 1, 1, zd, xa, fa, xi, fi)
      pmax = i
    endif
  endo
endp

library ("plot")
library ("smoother")
library ("pp")
; read the banknote data 
x = read ("bank2")
; select the fourth and sixth column and
; sphere the data
x = transform(x, grc.prep.sphere)
randomize(0)
; choose bandwidth related to Scott's rule
h = 2.62.*rows(x)^(-1/5)
; choose number of projections
n = 50
ppexample(x, h, n)

