; ---------------------------------------------------------------------
; EBook       mva
; ---------------------------------------------------------------------
; See_also    ppsj1ind
; ---------------------------------------------------------------------
; Macro       MVAppsjhous2
; ---------------------------------------------------------------------
; Description We read the Boston housing data and sphere them to run 
;             EPP on them. We select n (=20) randomly choosen one 
;             dimensional projections in the six dimensional space of
;             the data. For each set of projected data the 
;             Sibson-Jones-Index is applied to judge the 
;             "interestingness" of the projection.
;
;             In the graphics we see the density for the standard
;             normal distributed data (green) and the estimated
;             densities for the best (red) and the worst (blue)
;             projections found. Additionally we see a dotplot
;             of the projections. Below we see the estimated value
;             of the Sibson-Jones index for each computed projection 
;             (green = standard normal, red = best, blue = worst).
; ---------------------------------------------------------------------
; Author      Sigbert Klinke, 011102, Zdenek Hlavka, 020313
; ---------------------------------------------------------------------
proc(indmax)=ppexample(x, h, n)
  xg   = grid(-4, 0.1, 81)
  zd   = setmask(xg~pdfn(xg), "line", "green")
; select a starting vector
  p    = normal(cols(x))
  p    = p/sqrt(sum(p^2))
; compute index for starting vector
  xp   = x*p
  indmax = p
  imin = ppsj1ind(xp)
  imax = imin  
  xi   = setmask(grdot(xp), "blue")
  xi[,2] = -0.11-0.08*xi[,2]
  fi   = setmask(denxest(xp, h, "rqua", xg), "line", "blue")
  xa   = setmask(grdot(xp), "red")
  xa[,2] = -0.1-0.08*xa[,2]
  fa   = setmask(denxest(xp, h, "rqua", xg), "line", "red")
; create display 
  d    = createdisplay (2,1)
  setfractions(d,2|1,1)
  show (d, 1, 1, zd, xa, fa, xi, fi)
  inds = 0|imax
  pind = (1:rows(inds))~inds
  cind = 2|1
  setmaskp (pind, cind)
  show (d, 2, 1, pind)
; search for better projection vector
  i    = 0
  pmin = 1
  pmax = 1
  while (i<n)
    i   = i+1
    p   = normal(cols(x))
    p   = p/sqrt(sum(p^2))
    xp  = x*p
    ind = ppsj1ind(xp)
;    xi   = setmask(grdot(xp))
;    xi[,2] = -0.1.*xi[,2]
;    fi   = setmask(denxest(xp, h, "rqua", xg), "line")
;    show (d, 1, 1, zd, xs, fs, xf, ff, xi, fi)
    inds = inds|ind
    pind = (1:rows(inds))~inds
    cind = 0.*matrix(rows(pind))
    cind[maxind(inds)] = 4
    cind[minind(inds)] = 1
    cind[1] = 2
    setmaskp(pind, cind)
    show (d, 2, 1, pind)
    if (ind>imax)
      imax = ind
      indmax = p
      xa   = setmask(grdot(xp), "red")
      xa[,2] = -0.01-0.08.*xa[,2]
      fa   = setmask(denxest(xp, h, "rqua", xg), "line", "red")
      show (d, 1, 1, zd, xa, fa, xi, fi)
      pmin = i
    endif      
    if (ind<imin)
      imin = ind
      xi   = setmask(grdot(xp), "blue")
      xi[,2] = -0.11-0.08*xi[,2]
      fi   = setmask(denxest(xp, h, "rqua", xg), "line", "blue")
      show (d, 1, 1, zd, xa, fa, xi, fi)
      pmax = i
    endif
  endo
  indmax
endp

library ("plot")
library ("smoother")
library ("pp")
; read the boston housing data 
 x=read("bostonh")                      ; reads the data file
 x[506,14]=11.9													; fix the eof bug
 library("graphic")                     ; loads the graphic library
 x=log(x[,1])~x[,2]~log(x[,3])~x[,4]~log(x[,5:14])~(x[,14]>median(x[,14]))
 x=x[,1|3|5:14]                            
 x = transform(x, grc.prep.sphere)
randomize(0)
; choose bandwidth related to Scott's rule
h = 2.62.*rows(x)^(-1/5)
; choose number of projections
n = 500
axeson()
p=ppexample(x, h, n)

