; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      
; ----------------------------------------------------------------------------
;   Macro        MVAregzoom
; ----------------------------------------------------------------------------
;   Description   computes "blue pullover" example from amsa 
;                  script and adds vertical lines
;                   may be used for any simple linear regression 
;                   with intercept: modify line 12 & 13
; 
; Authors: Ralf Brueggemann, Sabine Krueger, Emanuel Moench, Christiane von Trotha
; 
; --------------------------------------------------------------------------------------
library("stats")
library("graphic")
library("xplore")
x=read("pullover")                              ; reads data    
dat = x[,2]~x[,1]                                   ; 1st column: x, 2nd column: y              
                                                                                                
cv    = cov(dat)                                    ; computes LS estimate              
sxy   = cv[2,1]                                         
sxx   = var(dat[,1])
beta  = sxy/sxx
alpha = mean(dat[,2]) - beta*mean(dat[,1])
y     = dat[,2]                                     ; generates fitted values
yhat  = alpha + beta * dat[,1]          
yquer = mean(dat[,2])*matrix(rows(x))
; --------------------------------------------------------------------------------------
; this block creates datasets for vertical lines
; --------------------------------------------------------------------------------------
line1 = vec((dat[,1]~dat[,1]~dat[,1])')    ~vec((yquer~y~yhat)')
line2 =(vec((dat[,1]~dat[,1]~dat[,1])')-.3)~vec((yquer~yhat~y)')
line3 =(vec((dat[,1]~dat[,1]~dat[,1])')+.3)~vec((y~yhat~yquer)')
; --------------------------------------------------------------------------------------
t = (round(min(dat[,1]))-5):(round(max(dat[,1])) +5) ; creates 'grid' for regression line
fit = alpha + beta*t                                 ; creates points on regression line
rl  = t~fit                                                              ; creates data for regression line     
ybar = t~mean(dat[,2])*matrix(rows(t))           ; generates data for mean line
; --------------------------------------------------------------------------------------
pm = (1:rows(t))'                            ; tells setmaskl which points to connect
i  = (reshape((1:(3*rows(x))), #(3,rows(x))))'
pm1= (vec((i[,1:2]~(0*matrix(rows(x), 1)))'))' ; tells setmaskl which points to connect
setmaskl (rl,    pm,  0, 1, 2)          ; for regression line 
setmaskl (ybar,  pm,  0, 2, 2)          ; for mean line
setmaskl (line1, pm1, 1, 1, 2)          ; for yquer~y
setmaskl (line2, pm1, 2, 1, 2)          ; for yquer~yhat
setmaskl (line3, pm1, 4, 1, 2)          ; for y~yhat
setmaskp (dat,  0, 3, 12)                   ; sets point style
setmaskp (rl,    4, 3, 0)                       
setmaskp (ybar,  4, 3, 0)
setmaskp (line1, 1, 3, 0)
setmaskp (line2, 1, 3, 0)
setmaskp (line3, 1, 3, 0)
;---------------------------------------------
d = createdisplay(1,1)
show (d,1,1,dat,rl, ybar, line1, line2, line3)
setgopt(d, 1, 1, "xlim", 88|102, "ylim", 162|198, "title", "pullover data","xlabel","price","ylabel","sales")
;-------------------------------------------

