; ----------------------------------------------------------------------------
;   EBook        mva
; ----------------------------------------------------------------------------
;   See_also     qff xdiag
; ----------------------------------------------------------------------------
;   Macro        MVAsimcibh
; ----------------------------------------------------------------------------
;   Description  MVAsimcibh tests the equality of 2 groups of Boston Housing data. 
;                It computes the F-statistic and the critical value of the test and
;                the simultaneous confidence intervals.
; ----------------------------------------------------------------------------
library("xplore")
; reads the Boston Housing data
x = read ("bostonh")	
			
; transforms the data
x = log(x[,1])~x[,2]~x[,3]~x[,4]~log(x[,5])~log(x[,6])~(x[,7]^(2.5))~log(x[,8])~log(x[,9])~log(x[,10])~exp(0.4*x[,11])/1000~x[,12]~sqrt(x[,13])~log(x[,14]) 

; makes the 2 groups and restricts the data
x1 = paf(x,x[,14]<=median(x[,14]))
x1 = x1[,1]~x1[,5]~x1[,8]~x1[,11]~x1[,13]
x2 = paf(x,x[,14]>median(x[,14]))
x2 = x2[,1]~x2[,5]~x2[,8]~x2[,11]~x2[,13]

n1 = rows(x1)
n2 = rows(x2)
n = n1+n2
p = cols(x1)

; estimates the mean and the variance
s1 = ((n1-1)/n1)*cov(x1)
s2 = ((n2-1)/n2)*cov(x2)
s = (n1*s1+n2*s2)/(n1+n2)
ex1 = mean(x1)
ex2 = mean(x2)
sinv = inv(s)
k = n1*n2*(n-p-1)/(p*(n^2))

; computes the test statistic
F = k*(ex1-ex2)*sinv*trans(ex1-ex2) ;(statistika 7.13b-ta dole)
F
; computes the critical value 
critvalue = qff(0.95,5,500)
critvalue

; computes the simultaneous confidence intervals
deltau = (ex1-ex2)'+sqrt(qff(0.95, p, n-p-1)*(1/k)*xdiag(s))
deltal = (ex1-ex2)'-sqrt(qff(0.95, p, n-p-1)*(1/k)*xdiag(s))

confint = deltal~deltau
confint


