; ----------------------------------------------------------------------------
; EBook         mva
; ----------------------------------------------------------------------------
;  See_also      mean cov
; ----------------------------------------------------------------------------
;   Macro        MVAstudisc
; ----------------------------------------------------------------------------
;   Description  MVAstudisc - discrimination analysis of MVA 2001 students
; ----------------------------------------------------------------------------
library("xplore")
library("stats")
; 
; DISCRIMINATION analysis of MVA students 2001
;
; the data
;
; x1 is height, x2 is shoe size,
; x3 (male=1, female=2) x4 (german=4, foreigner=3)
;
x1=#(185,182,174,180,169,180,160,162,175,180)
x2=#(45.5,43,41,43,41,43,36,36,39,39)
x3=#(1,1,1,1,1,1,0,0,0,0)
x4=#(3,4,4,4,3,3,3,3,3,4)
x=x1~x2~x3~x4
;
; uncomment for analysis of x4
;
;x3=x4-3
;
; calculate means and variances in groups

m1=mean(paf(x1~x2,x3==1))
m2=mean(paf(x1~x2,x3==0))
s1=cov(paf(x1~x2,x3==1))
s2=cov(paf(x1~x2,x3==0))
; calculate common variance
nm=sum(x3)
nf=10-sum(x3)
s=(nm/8)*s1+(nf/8)*s2
; alpha and m for the ML discrimination crit.

alpha=inv(s)*(m1-m2)'
m=0.5*(m1+m2)
; the criterion
d=((x1~x2)-m)*alpha
x~d
di=createdisplay(1,1)  		; create 1-window display 
; we set color of the points
x=setmask(x1~x2,"color",x3) 
x3
x=grsunflower(x1~x2,1|1,0|0,x3)
; calculate the line

ax1=m[,2]-((alpha[1]/alpha[2])*(160-m[,1]))
ax2=m[,2]-((alpha[1]/alpha[2])*(185-m[,1]))
; set the line
l=setmask(((160~ax1)|(185~ax2)),"line","blue","thin")
; show the points and the line

show(di, 1, 1,x,l) 		; datamatrix and smoot
setgopt(di,1,1,"title","Discrimination of MVA students","ylabel","Height","xlabel","Shoe Size")
       
